@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Mock data creation
 
-our $VERSION = '0.1500';
+our $VERSION = '0.1600';
 
 use strict;
 use warnings;
@@ -136,6 +136,7 @@ sub number_ranger {
     $args{end}    //= NDATA;
     $args{prec}   //= PREC;
     $args{random} //= 1;
+    $args{N}      ||= NDATA;
 
     # Bucket for our result list.
     my @results;
@@ -143,7 +144,7 @@ sub number_ranger {
     # Do we want random numbers?
     if ($args{random}) {
         # Roll!
-        for($args{start} .. $args{end}) {
+        for(1 .. $args{N}) {
             # Get our random candidate.
             my $x = rand($args{end});
             # Make sure it is above the start value.
@@ -397,7 +398,7 @@ Mock::Populate - Mock data creation
 
 =head1 VERSION
 
-version 0.1500
+version 0.1600
 
 =head1 SYNOPSIS
 
@@ -405,8 +406,8 @@ version 0.1500
   # * Call each function below with Mock::Populate::foo(...
   my $n      = 5;
   my $offset = 11;
-  my $ids    = number_ranger(start => 1, end => 1001, prec => 0, random => 0);
-  my $money  = number_ranger(start => 1000, end => 5000, prec => 2, random => 1);
+  my $ids    = number_ranger(start => 1, end => 1001, prec => 0, random => 0, N => $n);
+  my $money  = number_ranger(start => 1000, end => 5000, prec => 2, random => 1, N => $n);
   my $create = date_ranger(start => '1900-01-01', end => '2020-12-31', N => $n);
   my $modify = date_modifier($offset, @$create);
   my $times  = time_ranger(stamp => 1, start => '01:02:03', end =>'23:59:59', N => $n);
@@ -416,7 +417,7 @@ version 0.1500
   my $stats  = distributor(type => 'u', prec => 4, dof => 2, N => $n);
   my $string = string_ranger(length => 32, type => 'base64', N => $n);
   my $imgs   = image_ranger(size => 10, N => $n);  # *size is density, not pixel dimension
-  my $coll   = collate($ids, $people, $email, $create, $times, $modify, $times);
+  my $coll   = collate($ids, $people, $email, $create, $times);
 
 =head1 DESCRIPTION
 
@@ -479,16 +480,18 @@ determines if a time-stamp or the number of seconds should be returned.
     end    => $end,
     prec   => $prec,
     random => $random,
+    N      => $n,
   );
 
 Return a list of numbers within the range defined by B<start> and B<end>.  The
-B<start>, B<end>, B<prec>ision, and whether we want B<random> or sequential
+B<start>, B<end>, B<prec>ision, B<N>, and whether we want B<random> or sequential
 numbers are all optional.  The defaults are:
 
   start:     1
   end:       10
   precision: 2
   random:    1 (boolean)
+  N:         10
 
 =head2 name_ranger()
 
